import { useCallback, useContext, useEffect, useState } from "react";
import { Image, View, Text, Alert, BackHandler } from "react-native";
import { AppContext, AppSelectedUserDevice, AppStyles } from "../../utils";
import SettingsView from "./settings";
import SceneView from "./scene";
import {
  MyDeviceTabButton,
  MyDeviceTabButtonContainer,
} from "./deviceTabButton";
import { useFocusEffect } from "@react-navigation/native";

export default function DeviceScreen({ navigation }) {
  const appContext = useContext(AppContext);
  const [selectedView, setSelectedView] = useState(2);

  const SelectedView = () => {
    switch (selectedView) {
      case 0:
        return <SettingsView navigation={navigation} />;
      case 2:
        return <SceneView navigation={navigation} />;
      default:
        <Text>Not found</Text>;
    }
  };

  const getIconColor = (selectedViewNumber) => {
    return selectedView === selectedViewNumber
      ? appContext.appTheme.colors.primary
      : appContext.appTheme.icon;
  };

  useFocusEffect(
    useCallback(() => {
      const onBackPress = () => {
        if (selectedView === 0) {
        // This will switch from the device settings to the device scene view
          console.log("set selected view");
          setSelectedView(2);
          return true;
        }

         // This will close the app if the user is on the device screen on the scence view
        BackHandler.exitApp();
        return true;
      };

      BackHandler.addEventListener("hardwareBackPress", onBackPress);

      return () =>
        BackHandler.removeEventListener("hardwareBackPress", onBackPress);
    }, [selectedView])
  );

  /*
  useFocusEffect(
    useCallback(() => {
      console.log("open", AppSelectedUserDevice.current);

      const onBackPress = () => {
        if (selectedView === 0) {
          console.log("set selected view");
          setSelectedView(2);
          return true;
        } else {
          console.log("false");
          return false;
        }
      };

      const subscription = BackHandler.addEventListener(
        "hardwareBackPress",
        onBackPress
      );

      return () => {
        console.log("close");
        //subscription.remove();
        BackHandler.removeEventListener("hardwareBackPress", onBackPress);
      };
    }, [selectedView])
  ); */

  return (
    <View
      style={{
        height: "100%",
        backgroundColor: appContext.appTheme.backgroundColor,
      }}
    >
      <DeviceLivePreview />

      <MyDeviceTabButtonContainer>
        <MyDeviceTabButton
          iconName={"cog-outline"}
          selectedViewNumber={0}
          iconColor={getIconColor(0)}
          onPress={() => setSelectedView(0)}
        />
        <MyDeviceTabButton
          iconName={"rotate-3d-variant"}
          selectedViewNumber={1}
          iconColor={getIconColor(1)}
          onPress={() =>
            Alert.alert(
              "Rotate device",
              "Soon the device will turn 180 degrees"
            )
          }
        />
        <MyDeviceTabButton
          iconName={"group"}
          selectedViewNumber={2}
          iconColor={getIconColor(2)}
          onPress={() => setSelectedView(2)}
        />
      </MyDeviceTabButtonContainer>

      <View style={{ flex: 1 }}>
        <SelectedView />
      </View>
    </View>
  );
}

export function DeviceLivePreview() {
  const appContext = useContext(AppContext);

  return (
    <>
      {appContext.isUserDeveloperModeEnabled ? (
        <Image
          source={require("../../../assets/device.png")}
          style={[{ width: "100%" }, AppStyles.deviceLivePreview]}
          resizeMode="contain"
        />
      ) : (
        <View
          style={[
            {
              width: "100%",
              backgroundColor: "#ddd",
            },
            AppStyles.deviceLivePreview,
          ]}
        />
      )}
    </>
  );
}
